@@ -26,9 +26,6 @@ from argparse import RawDescriptionHelpFormatter
 import json
 from lodstorage.query import Query
 
-
-
-
 class WikiPush(object):
     '''
     Push pages from one MediaWiki to another
@@ -57,7 +54,13 @@ class WikiPush(object):
             if not self.toWiki.login():
                 raise Exception("can't login to target Wiki %s" % toWikiId )
         
-    def log(self,msg,end='\n'):
+    def log(self,msg:str,end='\n'):
+        """
+        show the given message if verbose is on
+        
+        Args:
+            msg(str): the message to display
+        """
         if self.verbose:
             print (msg,end=end)
             
